==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/IBMCloudPlatformSpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class IBMCloudPlatformSpecBuilder extends io.fabric8.openshift.api.model.IBMCloudPlatformSpecFluentImpl<io.fabric8.openshift.api.model.IBMCloudPlatformSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.IBMCloudPlatformSpec,io.fabric8.openshift.api.model.IBMCloudPlatformSpecBuilder>{
  public IBMCloudPlatformSpecBuilder() {
    this(false);
  }
  public IBMCloudPlatformSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new IBMCloudPlatformSpec(), validationEnabled);
  }
  public IBMCloudPlatformSpecBuilder(io.fabric8.openshift.api.model.IBMCloudPlatformSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public IBMCloudPlatformSpecBuilder(io.fabric8.openshift.api.model.IBMCloudPlatformSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new IBMCloudPlatformSpec(), validationEnabled);
  }
  public IBMCloudPlatformSpecBuilder(io.fabric8.openshift.api.model.IBMCloudPlatformSpecFluent<?> fluent,io.fabric8.openshift.api.model.IBMCloudPlatformSpec instance) {
    this(fluent, instance, false);
  }
  public IBMCloudPlatformSpecBuilder(io.fabric8.openshift.api.model.IBMCloudPlatformSpecFluent<?> fluent,io.fabric8.openshift.api.model.IBMCloudPlatformSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    this.validationEnabled = validationEnabled; 
  }
  public IBMCloudPlatformSpecBuilder(io.fabric8.openshift.api.model.IBMCloudPlatformSpec instance) {
    this(instance,false);
  }
  public IBMCloudPlatformSpecBuilder(io.fabric8.openshift.api.model.IBMCloudPlatformSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.IBMCloudPlatformSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.IBMCloudPlatformSpec build() {
    IBMCloudPlatformSpec buildable = new IBMCloudPlatformSpec();
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IBMCloudPlatformSpecBuilder that = (IBMCloudPlatformSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/IBMCloudPlatformSpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class IBMCloudPlatformSpecBuilder extends io.fabric8.openshift.api.model.IBMCloudPlatformSpecFluentImpl<io.fabric8.openshift.api.model.IBMCloudPlatformSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.IBMCloudPlatformSpec,io.fabric8.openshift.api.model.IBMCloudPlatformSpecBuilder>{
  public IBMCloudPlatformSpecBuilder() {
    this(false);
  }
  public IBMCloudPlatformSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new IBMCloudPlatformSpec(), validationEnabled);
  }
  public IBMCloudPlatformSpecBuilder(io.fabric8.openshift.api.model.IBMCloudPlatformSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public IBMCloudPlatformSpecBuilder(io.fabric8.openshift.api.model.IBMCloudPlatformSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new IBMCloudPlatformSpec(), validationEnabled);
  }
  public IBMCloudPlatformSpecBuilder(io.fabric8.openshift.api.model.IBMCloudPlatformSpecFluent<?> fluent,io.fabric8.openshift.api.model.IBMCloudPlatformSpec instance) {
    this(fluent, instance, false);
  }
  public IBMCloudPlatformSpecBuilder(io.fabric8.openshift.api.model.IBMCloudPlatformSpecFluent<?> fluent,io.fabric8.openshift.api.model.IBMCloudPlatformSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public IBMCloudPlatformSpecBuilder(io.fabric8.openshift.api.model.IBMCloudPlatformSpec instance) {
    this(instance,false);
  }
  public IBMCloudPlatformSpecBuilder(io.fabric8.openshift.api.model.IBMCloudPlatformSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.IBMCloudPlatformSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.IBMCloudPlatformSpec build() {
    IBMCloudPlatformSpec buildable = new IBMCloudPlatformSpec();
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IBMCloudPlatformSpecBuilder that = (IBMCloudPlatformSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
